# TAC Control

## Description

This is the skill for managing a TAC.

This skill is part of the Fetch.ai TAC demo. It manages the progression of the competition along its various stages.

## Behaviours

* `tac`: manages progression of the competition 

## Handlers

* `tac`: handles `tac` messages for managing the competition
* `oef`: handles `oef_search` messages if registration or unregistration on the sOEF is unsuccessful

## Links

* <a href="https://docs.fetch.ai/aea/tac-skills-contract/" target="_blank">TAC Demo</a>
